==> scriptcase-9.5.003-pt_br-php7.3.zip: scriptcase-9.5.003-pt_br-php7.3/devel/lib/php/default_values/Apl_attr4.php <==
<?php
        $def_dados = array();

		$def_dados['criargrid'] = "";
		$def_dados['criaredit'] = "";
		$def_dados['criarsearch'] = "N";
		$def_dados['gridlinhaspagina'] = "";
		$def_dados['gridlinhaspaginanumero'] = "";
		$def_dados['grid_label_fixo'] = "N";
		$def_dados['grid_lazy_inc'] = "5";
		$def_dados['grid_lazy_altura'] = "";
		$def_dados['grid_lazy_abrir_modal'] = "S";
		$def_dados['grid_lazy_manter_estado'] = "S";
		$def_dados['gridmostranumlinha'] = "S";
		$def_dados['usa_ajax'] = "S";
        $def_dados['edit_form_modal_use'] = "N";
        $def_dados['edit_form_modal_width'] = "500";
        $def_dados['edit_form_modal_height'] = "450";
		$def_dados['gridmostracabecalho'] = "S";
		$def_dados['tooltip_expanded'] = "N";
		$def_dados['adaptive_y_axis'] = "N";
		$def_dados['editavanca'] = "";
		$def_dados['editretorna'] = "";
		$def_dados['editinicio'] = "";
		$def_dados['editfinal'] = "";
		$def_dados['editnovo'] = "S";
		$def_dados['editincluir'] = "";
		$def_dados['editalterar'] = "";
		$def_dados['editexcluir'] = "";
		$def_dados['searchbrancoall'] = "";
		$def_dados['quicksearch_keepfiltercondition'] = "S";
		$def_dados['searchtipo'] = "";
		$def_dados['urlsaidaaplicacao'] = "";
		$def_dados['editformatohtml'] = "";
		$def_dados['editformatoframe'] = "";
		$def_dados['criardetalhe'] = "";
		$def_dados['detalhetipo'] = "";
		$def_dados['detalhe_modal_largura'] = "";
		$def_dados['detalhe_modal_altura'] = "";
		$def_dados['searchcond'] = "";
		$def_dados['apliniciar'] = "";
		$def_dados['gridorientacao'] = "";
		$def_dados['gridcolunaspaginanumero'] = "";
		$def_dados['gridpostotal'] = "";
		$def_dados['gridpermiteqtd'] = "";
		$def_dados['gridposquebra'] = "";
		$def_dados['gridtotalafter'] = "";
		$def_dados['gridcabecalhoini'] = "";
		$def_dados['gridmostraresumo'] = "";
		$def_dados['gridposresumo'] = "";
		$def_dados['criarpdf'] = "";
		$def_dados['barrapospagina'] = "";
		$def_dados['barraposbotoes'] = "";
		$def_dados['criarxml'] = "";
		$def_dados['criarcsv'] = "";
		$def_dados['criarhtmlvisualizacao'] = "";
		$def_dados['criarhtmlimpressao'] = "";
		$def_dados['cons_params'] = "";
		$def_dados['form_params'] = "";
		$def_dados['liga_aplicacao'] = "";
		$def_dados['liga_campos'] = "";
		$def_dados['cabecalho_pesq'] = "";
		$def_dados['titulo_grid'] = "";
		$def_dados['titulo_pesq'] = "";
		$def_dados['titulo_detalhe'] = "";
		$def_dados['titulo_insert'] = "";
		$def_dados['titulo_update'] = "";
		$def_dados['cabecalho_grid'] = "";
		$def_dados['cabecalho_grid_mobile_mostra'] = "S";
		$def_dados['cabecalho_grid_mobile'] = "";
		$def_dados['template_grid_mobile'] = "scriptcase__NM__flatmobile";
		$def_dados['cabecalho_edit'] = "";
		$def_dados['cabecalho_detalhe'] = "";
		$def_dados['usa_distinct'] = "";
		$def_dados['timeout_cons'] = "";
		$def_dados['timeout_form'] = "";
		$def_dados['quebra_forca'] = "";
		$def_dados['js_formata'] = "";
		$def_dados['resumo_count'] = "";
		$def_dados['graf_count'] = "";
		$def_dados['graf_num_linha'] = "S";
		$def_dados['graf_habilitar_hover'] = "S";
		$def_dados['graf_label_total'] = "2";
		$def_dados['graf_altura'] = "";
		$def_dados['graf_largura'] = "";
		$def_dados['graf_tipo'] = "";
		$def_dados['timestamp'] = "";
		$def_dados['graf_margem'] = "";
		$def_dados['graf_aspecto'] = "";
		$def_dados['pdf_formato'] = "8";
		$def_dados['pdf_orientacao'] = "1";
		$def_dados['criardoc'] = "";
		$def_dados['gridpermiteseq'] = "";
		$def_dados['vert_total_coluna'] = "";
		$def_dados['imagem_path'] = "";
		$def_dados['exibir_sumario'] = "";
		$def_dados['use_new_hotkeys'] = "N";
		$def_dados['use_new_hotkeys_filter'] = "N";
		$def_dados['use_new_hotkeys_detail'] = "N";
		$def_dados['use_new_hotkeys_resume'] = "N";
		$def_dados['mobile_display_scrollup'] = "N";
		$def_dados['use_mobile_improvements'] = "N";
		$def_dados['use_mobile_improvements_detail'] = "N";
		$def_dados['use_mobile_improvements_search'] = "N";
		$def_dados['use_mobile_improvements_summary'] = "N";
		$def_dados['mobile_display_options_button'] = "N";
		$def_dados['mobile_display_options_button_detail'] = "N";
		$def_dados['mobile_display_options_button_search'] = "N";
		$def_dados['mobile_display_options_button_summary'] = "N";
		$def_dados['mobile_toolbar_orientation'] = "H";
		$def_dados['mobile_toolbar_orientation_detail'] = "H";
		$def_dados['mobile_toolbar_orientation_search'] = "H";
		$def_dados['mobile_toolbar_orientation_summary'] = "H";
		$def_dados['mobile_navigation_bar_buttons'] = ['NP', 'FL', 'RC'];
		$def_dados['mobile_scrollup_position'] = "A";
		$def_dados['align_detalhe'] = "";
		$def_dados['align_grid_vert'] = "";
		$def_dados['criarpdfblack'] = "";
		$def_dados['criarexcel'] = "";
		$def_dados['exibir_erro_sql'] = "";
		$def_dados['exibir_erro_script'] = "";
		$def_dados['num_col_slide'] = "";
		$def_dados['pdf_linhas_pagina'] = "";
		$def_dados['redirect_url'] = "";
		$def_dados['redirect_var'] = "";
		$def_dados['grid_colunas_usar'] = "A";
		$def_dados['pdf_botao_abre'] = "S";
		$def_dados['xml_botao_abre'] = "";
		$def_dados['json_botao_abre'] = 'N';
		$def_dados['grupo_edit'] = "S";
		$def_dados['tabela_largura'] = "0";
		$def_dados['tabela_unidade'] = "AT";
        $def_dados['coluna_largura'] = "120px";
        $def_dados['print_show_button'] = 'S';
        $def_dados['print_format_date'] = '';
        $def_dados['print_show_title'] = '{lang_events_order}';
        $def_dados['print_fields_extra'] = '';
        $def_dados['sort_advanced_options'] = 'grid';
        $def_dados['sort_advanced_show_sort_icon_mouseover'] = 'S';
        $def_dados['form_show_sort_icon_mouseover'] = 'S';
        $def_dados['summary_show_sort_icon_mouseover'] = 'S';
        $def_dados['sort_advanced_fields'] = '';
        $def_dados['refined_search_move_searched_top'] = 'N';
        $def_dados['refined_search_show_qtd_result'] = 'S';
        $def_dados['refined_search_started_opened'] = 'aberto';
        $def_dados['refined_search_min_width'] = "260px";
        $def_dados['refined_search_max_width'] = "";
        $def_dados['refined_search_min_height'] = "";
        $def_dados['refined_search_max_height'] = "";
        $def_dados['chart_new_version'] = 'N';
        $def_dados['chart_desktop_responsive'] = 'S';
        $def_dados['chart_types_available'] = 'bar2d;bar3d;column2d;column3d;line;spline;step;area;areaspline;stackedbar2d;stackedbar3d;stackedcolumn2d;stackedcolumn3d;stackedarea;pie2d;pie3d;doughnut2d;doughnut3d;combination2d;combination3d;pyramid;pyramid2d;funnel;funnel2d;radar;angulargauge;semicirculargauge;hlineargauge;scatter;bubble';
        $def_dados['chart_label_count'] = '';
        $def_dados['chart_label_summ'] = '';
        $def_dados['chart_title_name'] = '';
        $def_dados['chart_new_theme'] = 'csstheme';
        $def_dados['chart_new_type'] = 'column2d';
        $def_dados['css_tab_min_width'] = '';
        $def_dados['css_tab_max_width'] = '';
        $def_dados['chart_display_value_except'] = 'pie;pyramid;funnel';
        $def_dados['chart_orientacao_eixo_x'] = 'horizontal';
		$def_dados['editor_html_template_usar']       = 'S';
		$def_dados['control_html_source'] = 'input';
		$def_dados['control_html_content'] = '<html>

<head>
	<!--SC_PAGE_CHARSET-->
	<!--SC_JS_LIB-->
	<link rel="stylesheet" type="text/css" href="__SC_CTRL_HTML_APP__NAME__.css" />
	<script type="text/javascript" src="__SC_CTRL_HTML_APP__NAME__.js"></script>
	<title><!--SC_PAGE_TITLE--></title>
</head>

<body>
<form {SC_FORM_ATTR}>
<!--SC_FORM_HIDDEN-->
<!--SC_FIELD_LABEL_my_field-->
<br />
<!--SC_FIELD_INI_my_field-->
<input {SC_FIELD_INFO_my_field} class="{SC_FIELD_CLASS}" type="text" />
<!--SC_FIELD_END_my_field-->
<br />
<input type="button" {SC_FORM_SUBMIT_INFO} />
</form>
</body>

</html>';
		$def_dados['control_html_css'] = '';
		$def_dados['control_html_js'] = 'function scDisplayUserError(errorMessage) {
	alert("ERROR\r\n" + errorMessage.replace(/<br \/>/gi, "\\n"));
}
function scDisplayUserDebug(debugMessage) {
	alert("DEBUG\r\n" + debugMessage.replace(/<br \/>/gi, "\\n"));
}function scDisplayUserMessage(userMessage) {
	alert("MESSAGE\r\n" + userMessage.replace(/<br \/>/gi, "\\n"));
}';
		$def_dados['control_html_file'] = '';
		$def_dados['chart_theme'] = array();
		$def_dados['Formata_Moeda'] = 'N';
		$def_dados['Moeda_Simbolo'] = '';
		$def_dados['Simbolo_Agr'] = '';
		$def_dados['Simbolo_Dec'] = '';
		$def_dados['Casas_Decimais'] = '0';
		$def_dados['Mostra_Zeros'] = 'S';
		$def_dados['Valor_Extenso'] = 'N';
		$def_dados['Valor_Extenso_Tamanho'] = '0';
		$def_dados['usar_config_regional'] = 'S';
		$def_dados['cor_negativo'] = '';
		$def_dados['simbolo_negativo'] = '';
		$def_dados['formato_num_negativo'] = '';
		$def_dados['event_friendly_project'] ='N';
		$def_dados['exportemail_to']     ='';
		$def_dados['exportemail_has_cc'] ='N';
		$def_dados['exportemail_cc']     ='';
		$def_dados['exportemail_has_bcc']='N';
		$def_dados['exportemail_bcc']    ='';
		$def_dados['exportemail_subject']='{lang_export_email_subject}';
		$def_dados['exportemail_email']  ='{lang_export_email_body}';
		$def_dados['mail_api_settings']  ='';

?>

==> scriptcase-9.13.009-pt_br-php8.1.zip: scriptcase-9.13.009-pt_br-php8.1/devel/lib/php/default_values/Apl_attr4.php <==
<?php
        $def_dados = array();

		$def_dados['criargrid'] = "";
		$def_dados['criaredit'] = "";
		$def_dados['criarsearch'] = "N";
		$def_dados['gridlinhaspagina'] = "";
		$def_dados['gridlinhaspaginanumero'] = "";
		$def_dados['summary_gridlinhaspagina'] = "1";
		$def_dados['summary_gridlinhaspaginanumero'] = "10";
		$def_dados['grid_label_fixo'] = "N";
		$def_dados['grid_coluna_fixa'] = "N";
		$def_dados['grid_coluna_fixa_hover'] = "S";
		$def_dados['grid_coluna_fixa_actions'] = "S";
		$def_dados['grid_quebra_fixa'] = "N";
		$def_dados['grid_lazy_inc'] = "5";
		$def_dados['grid_lazy_altura'] = "";
		$def_dados['grid_lazy_abrir_modal'] = "S";
		$def_dados['grid_lazy_manter_estado'] = "S";
		$def_dados['gridmostranumlinha'] = "S";
		$def_dados['usa_ajax'] = "S";
        $def_dados['edit_form_modal_use'] = "N";
        $def_dados['edit_form_modal_width'] = "500";
        $def_dados['edit_form_modal_height'] = "450";
		$def_dados['gridmostracabecalho'] = "S";
		$def_dados['tooltip_expanded'] = "N";
		$def_dados['adaptive_y_axis'] = "N";
		$def_dados['editavanca'] = "";
		$def_dados['editavanca'] = "";
		$def_dados['editstepavanca'] = "";
		$def_dados['editretorna'] = "";
		$def_dados['editstepretorna'] = "";
		$def_dados['editinicio'] = "";
		$def_dados['editfinal'] = "";
		$def_dados['editnovo'] = "S";
		$def_dados['editincluir'] = "";
		$def_dados['editalterar'] = "";
		$def_dados['editexcluir'] = "";
		$def_dados['searchbrancoall'] = "";
		$def_dados['quicksearch_keepfiltercondition'] = "S";
		$def_dados['searchtipo'] = "";
		$def_dados['urlsaidaaplicacao'] = "";
		$def_dados['editformatohtml'] = "";
		$def_dados['editformatoframe'] = "";
		$def_dados['criardetalhe'] = "";
		$def_dados['detalhetipo'] = "";
		$def_dados['detalhe_modal_largura'] = "";
		$def_dados['detalhe_modal_altura'] = "";
		$def_dados['detalhe_compact'] = "N";
		$def_dados['detalhe_no_margin'] = "N";
		$def_dados['detalhe_no_border'] = "N";
		$def_dados['searchcond'] = "";
		$def_dados['apliniciar'] = "";
		$def_dados['gridorientacao'] = "";
		$def_dados['gridcolunaspaginanumero'] = "";
		$def_dados['gridpostotal'] = "";
		$def_dados['summary_gridpostotal'] = "2";
		$def_dados['gridpermiteqtd'] = "";
		$def_dados['gridposquebra'] = "";
		$def_dados['gridtotalafter'] = "";
		$def_dados['gridcabecalhoini'] = "";
		$def_dados['gridmostraresumo'] = "";
		$def_dados['gridposresumo'] = "";
		$def_dados['criarpdf'] = "";
		$def_dados['barrapospagina'] = "";
		$def_dados['barraposbotoes'] = "";
		$def_dados['criarxml'] = "";
		$def_dados['criarcsv'] = "";
		$def_dados['criarhtmlvisualizacao'] = "";
		$def_dados['criarhtmlimpressao'] = "";
		$def_dados['cons_params'] = "";
		$def_dados['form_params'] = "";
		$def_dados['liga_aplicacao'] = "";
		$def_dados['liga_campos'] = "";
		$def_dados['cabecalho_pesq'] = "";
		$def_dados['titulo_grid'] = "";
		$def_dados['titulo_pesq'] = "";
		$def_dados['titulo_detalhe'] = "";
		$def_dados['titulo_insert'] = "";
		$def_dados['titulo_update'] = "";
		$def_dados['cabecalho_grid'] = "";
		$def_dados['cabecalho_edit'] = "";
		$def_dados['cabecalho_detalhe'] = "";
		$def_dados['usa_distinct'] = "";
		$def_dados['timeout_cons'] = "";
		$def_dados['timeout_form'] = "";
		$def_dados['quebra_forca'] = "";
		$def_dados['js_formata'] = "";
		$def_dados['resumo_count'] = "";
		$def_dados['graf_count'] = "";
		$def_dados['graf_num_linha'] = "S";
		$def_dados['graf_habilitar_hover'] = "S";
		$def_dados['graf_label_total'] = "2";
		$def_dados['graf_altura'] = "";
		$def_dados['graf_largura'] = "1200";
		$def_dados['graf_tipo'] = "";
		$def_dados['timestamp'] = "";
		$def_dados['graf_margem'] = "";
		$def_dados['graf_aspecto'] = "";
		$def_dados['pdf_formato'] = "8";
		$def_dados['pdf_orientacao'] = "1";
		$def_dados['criardoc'] = "";
		$def_dados['gridpermiteseq'] = "";
		$def_dados['vert_total_coluna'] = "";
		$def_dados['imagem_path'] = "";
		$def_dados['exibir_sumario'] = "";
		$def_dados['summary_exibir_sumario'] = "";
		$def_dados['form_exibir_sumario'] = "";
		$def_dados['use_new_hotkeys'] = "N";
		$def_dados['use_new_hotkeys_filter'] = "N";
		$def_dados['use_new_hotkeys_detail'] = "N";
		$def_dados['use_new_hotkeys_resume'] = "N";
		$def_dados['mobile_display_scrollup'] = "S";
		$def_dados['use_mobile_improvements'] = "N";
		$def_dados['use_mobile_improvements_detail'] = "N";
		$def_dados['use_mobile_improvements_search'] = "N";
		$def_dados['use_mobile_improvements_summary'] = "N";
		$def_dados['mobile_display_options_button'] = "N";
		$def_dados['mobile_display_options_button_detail'] = "N";
		$def_dados['mobile_display_options_button_search'] = "N";
		$def_dados['mobile_display_options_button_summary'] = "N";
		$def_dados['mobile_toolbar_orientation'] = "H";
		$def_dados['mobile_toolbar_orientation_detail'] = "H";
		$def_dados['mobile_toolbar_orientation_search'] = "H";
		$def_dados['mobile_toolbar_orientation_summary'] = "H";
		$def_dados['mobile_navigation_bar_buttons'] = ['NP', 'FL', 'RC'];
		$def_dados['mobile_scrollup_position'] = "A";
		$def_dados['mobile_toolbar_simple'] = "S";
		$def_dados['mobile_toolbar_bottom_fixed'] = "S";
		$def_dados['align_detalhe'] = "";
		$def_dados['align_grid_vert'] = "";
		$def_dados['criarpdfblack'] = "";
		$def_dados['criarexcel'] = "";
		$def_dados['exibir_erro_sql'] = "";
		$def_dados['exibir_erro_script'] = "";
		$def_dados['num_col_slide'] = "";
		$def_dados['pdf_linhas_pagina'] = "";
		$def_dados['redirect_url'] = "";
		$def_dados['redirect_var'] = "";
		$def_dados['grid_colunas_usar'] = "A";
		$def_dados['pdf_botao_abre'] = "S";
		$def_dados['pdf_botao_abre_progressbar'] = "N";
		$def_dados['xml_botao_abre'] = "";
		$def_dados['json_botao_abre'] = 'N';
		$def_dados['grupo_edit'] = "S";
		$def_dados['tabela_largura'] = "0";
		$def_dados['tabela_unidade'] = "AT";
        $def_dados['coluna_largura'] = "120px";
        $def_dados['print_show_button'] = 'S';
        $def_dados['print_format_date'] = '';
        $def_dados['print_show_title'] = '{lang_events_order}';
        $def_dados['print_fields_extra'] = '';
        $def_dados['sort_advanced_options'] = 'grid';
        $def_dados['sort_advanced_show_sort_icon_mouseover'] = 'S';
        $def_dados['form_show_sort_icon_mouseover'] = 'S';
        $def_dados['summary_show_sort_icon_mouseover'] = 'S';
        $def_dados['sort_advanced_fields'] = '';
        $def_dados['refined_search_move_searched_top'] = 'S';
        $def_dados['refined_search_collapse'] = 'N';
        $def_dados['refined_search_collapse_start'] = 'aberto';
        $def_dados['refined_search_show_qtd_result'] = 'S';
        $def_dados['refined_search_started_opened'] = 'aberto';
        $def_dados['refined_search_min_width'] = "260px";
        $def_dados['refined_search_max_width'] = "";
        $def_dados['refined_search_min_height'] = "";
        $def_dados['refined_search_max_height'] = "";
        $def_dados['refined_search_use_modal'] = "N";
        $def_dados['refined_search_col_modal'] = "3";
        $def_dados['refined_search_height_modal'] = "";
        $def_dados['refined_search_width_modal'] = "";
        $def_dados['refined_search_show_tags'] = "N";
        $def_dados['refined_search_only_checkbox'] = "N";
        $def_dados['refined_search_submit_checkbox'] = "N";
        $def_dados['refined_search_start_checked'] = "S";
        $def_dados['chart_desktop_responsive'] = 'S';
        $def_dados['chart_types_available'] = 'bar2d;bar3d;scrollbar2d;overlappedbar2d;column2d;column3d;scrollcolumn2d;overlappedcolumn2d;line;scrollline2d;zoomline;spline;step;area;areaspline;scrollarea2d;stackedbar2d;stackedbar3d;stackedcolumn2d;stackedcolumn3d;stackedarea;pie2d;pie3d;doughnut2d;doughnut3d;combination2d;combination3d;pyramid;pyramid2d;funnel;funnel2d;radar;angulargauge;semicirculargauge;hlineargauge;scatter;bubble;heatmap;treemap;chord;sankey;sunburst';
        $def_dados['chart_label_count'] = '';
        $def_dados['chart_label_summ'] = '';
        $def_dados['chart_title_name'] = '';
		$def_dados['chart_title_fill'] = 'N';
		$def_dados['gantt_title_name'] = '';
        $def_dados['chart_new_theme'] = 'csstheme';
        $def_dados['chart_new_type'] = 'column2d';
        $def_dados['css_tab_min_width'] = '';
        $def_dados['css_tab_max_width'] = '';
        $def_dados['chart_display_value_except'] = 'pie;pyramid;funnel';
		$def_dados['chart_orientacao_eixo_x'] = 'horizontal';
		$def_dados['chart_limit_items'] = '';
		$def_dados['chart_inline_summary'] = 'N';
		$def_dados['chart_inline_width'] = '1200';
		$def_dados['chart_inline_height'] = '400';
		$def_dados['editor_html_template_usar']       = 'S';
		$def_dados['control_html_source'] = 'input';
		$def_dados['control_html_content'] = '<html>

<head>
	<!--SC_PAGE_CHARSET-->
	<!--SC_JS_LIB-->
	<link rel="stylesheet" type="text/css" href="__SC_CTRL_HTML_APP__NAME__.css" />
	<script type="text/javascript" src="__SC_CTRL_HTML_APP__NAME__.js"></script>
	<title><!--SC_PAGE_TITLE--></title>
</head>

<body>
<form {SC_FORM_ATTR}>
<!--SC_FORM_HIDDEN-->
<!--SC_FIELD_LABEL_my_field-->
<br />
<!--SC_FIELD_INI_my_field-->
<input {SC_FIELD_INFO_my_field} class="{SC_FIELD_CLASS}" type="text" />
<!--SC_FIELD_END_my_field-->
<br />
<input type="button" {SC_FORM_SUBMIT_INFO} />
</form>
</body>

</html>';
		$def_dados['control_html_css'] = '';
		$def_dados['control_html_js'] = '';
		$def_dados['control_html_file'] = '';
		$def_dados['chart_theme'] = array();
		$def_dados['Formata_Moeda'] = 'N';
		$def_dados['Moeda_Simbolo'] = '';
		$def_dados['Simbolo_Agr'] = '';
		$def_dados['Simbolo_Dec'] = '';
		$def_dados['Casas_Decimais'] = '0';
		$def_dados['Mostra_Zeros'] = 'S';
		$def_dados['Valor_Extenso'] = 'N';
		$def_dados['Valor_Extenso_Tamanho'] = '0';
		$def_dados['usar_config_regional'] = 'S';
		$def_dados['cor_negativo'] = '';
		$def_dados['simbolo_negativo'] = '';
		$def_dados['formato_num_negativo'] = '';
		$def_dados['event_friendly_project'] ='N';
		$def_dados['exportemail_to']     ='';
		$def_dados['exportemail_has_cc'] ='N';
		$def_dados['exportemail_cc']     ='';
		$def_dados['exportemail_has_bcc']='N';
		$def_dados['exportemail_bcc']    ='';
		$def_dados['exportemail_subject']='{lang_export_email_subject}';
		$def_dados['exportemail_email']  ='{lang_export_email_body}';
		$def_dados['mail_api_settings']  ='';
		$def_dados['save_grid_state_session']  ='N';
		$def_dados['save_grid_state_session_mode']  = "button";
		$def_dados['save_grid_state_session_load']  = "N";
		$def_dados['save_grid_modules']  = array('filter','columns','groupby','sorting');
		$def_dados['save_grid_format']  = "extended";
		$def_dados['display_control_html_errors'] = 'div';
		$def_dados['wizard_form'] = 'N';
		$def_dados['wizard_insert_button'] = 'hide';
		$def_dados['wizard_navigate_button'] = 'hide';
		$def_dados['wizard_template'] = 'boxed';
		$def_dados['wizard_template_mobile'] = 'N';
		$def_dados['wizard_size'] = '';
		$def_dados['wizard_position'] = 'left';
		$def_dados['wizard_title_font'] = '';
		$def_dados['wizard_title_size'] = '';
		$def_dados['wizard_title_color_complete'] = '';
		$def_dados['wizard_title_color_now'] = '';
		$def_dados['wizard_title_color_next'] = '';
		$def_dados['wizard_title_color_todo'] = '';
		$def_dados['wizard_desc_font'] = '';
		$def_dados['wizard_desc_size'] = '';
		$def_dados['wizard_desc_color_complete'] = '';
		$def_dados['wizard_desc_color_now'] = '';
		$def_dados['wizard_desc_color_next'] = '';
		$def_dados['wizard_desc_color_todo'] = '';
		$def_dados['wizard_update_mode'] = 'wizard';
		$def_dados['wizard_width'] = '100p';
		$def_dados['wizard_navigate_behavior'] = 'actual';
		$def_dados['grid_order_icons'] = 'fa';
		$def_dados['grid_order_icons_alpha'] = 'alpha';
		$def_dados['grid_order_icons_numeric'] = 'numeric';
		$def_dados['form_view_qsearch_grid_only'] = 'N';
		$def_dados['googlesheets_api'] = '';
		$def_dados['googlesheets_name'] = '';
		$def_dados['id_googlesheets_parent'] = '';
		$def_dados['googlesheets_parentid'] = '';
		$def_dados['googlesheets_fileid'] = '';
		$def_dados['googlesheets_fields'] = '';
		$def_dados['campos_order'] = '';

?>
